@@ -534,7 +534,7 @@ class ElementWrapper(object):
             values = []
 
         if isinstance(values, bool):
-            self.checked = True
+            self.checked = values
 
         elif values and all(isinstance(v, bool) for v in values):
             # List of bools, eg ``[True, False, True]``
